@@ -102,8 +102,7 @@ def request(method, url, **kwargs):
 
 for name in ("GET", "OPTIONS", "HEAD", "POST", "PUT", "PATCH", "DELETE"):
     __all__.append(name.lower())
-    globals()[name.lower()] = lambda url, _=name, **kwargs: request(_, url, **kwargs)
-'''
+    globals()[name.lower()] = lambda url, _=name, **kwargs: request(_, url, **kwargs)'''
 
 def apply_patch():  
     requests2_path = "/lib/python3.9/site-packages/requests2"
